"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Signer = void 0;
const bundle_1 = require("./types/bundle");
const fulcio_1 = require("./types/fulcio");
const rekor_1 = require("./types/rekor");
const util_1 = require("./util");
class Signer {
    constructor(options) {
        this.identityProviders = [];
        this.fulcio = options.fulcio;
        this.rekor = options.rekor;
        this.identityProviders = options.identityProviders;
    }
    async signBlob(payload) {
        // Get signature and signing certificate for payload
        const { signature, certificates } = await this.sign(payload);
        // Calculate artifact digest
        const digest = util_1.crypto.hash(payload);
        const leafCertificate = certificates[0];
        // Create Rekor entry
        const proposedEntry = rekor_1.rekor.toProposedHashedRekordEntry(digest, signature, leafCertificate);
        const entry = await this.rekor.createEntry(proposedEntry);
        return bundle_1.bundle.toMessageSignatureBundle(digest, signature, certificates, entry);
    }
    async signAttestation(payload, payloadType) {
        // Pre-authentication encoding to be signed
        const paeBuffer = util_1.dsse.preAuthEncoding(payloadType, payload);
        // Get signature and signing certificate for pae
        const { signature, certificates } = await this.sign(paeBuffer);
        const envelope = {
            payloadType,
            payload: payload,
            signatures: [
                {
                    keyid: '',
                    sig: signature,
                },
            ],
        };
        const signingCertificate = certificates[0];
        const proposedEntry = rekor_1.rekor.toProposedIntotoEntry(envelope, signingCertificate);
        const entry = await this.rekor.createEntry(proposedEntry);
        return bundle_1.bundle.toDSSEBundle(envelope, certificates, entry);
    }
    async sign(payload) {
        // Create emphemeral key pair
        const keypair = util_1.crypto.generateKeyPair();
        // Retrieve identity token from one of the supplied identity providers
        const identityToken = await this.getIdentityToken();
        // Extract challenge claim from OIDC token
        const subject = util_1.oidc.extractJWTSubject(identityToken);
        // Construct challenge value by encrypting subject with private key
        const challenge = util_1.crypto.signBlob(Buffer.from(subject), keypair.privateKey);
        // Create signing certificate
        const certificate = await this.fulcio.createSigningCertificate(identityToken, fulcio_1.fulcio.toCertificateRequest(keypair.publicKey, challenge));
        // Generate artifact signature
        const signature = util_1.crypto.signBlob(payload, keypair.privateKey);
        return {
            signature,
            certificates: util_1.pem.split(certificate),
        };
    }
    async getIdentityToken() {
        const aggErrs = [];
        for (const provider of this.identityProviders) {
            try {
                const token = await provider.getToken();
                if (token) {
                    return token;
                }
            }
            catch (err) {
                aggErrs.push(err);
            }
        }
        throw new Error(`Identity token providers failed: ${aggErrs}`);
    }
}
exports.Signer = Signer;
